@@ -74,6 +74,11 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new AccountsConnector(configuration, sessionData);
     }
 
+    @Override
+    public AllCapabilitiesConnector getAllCapabilities(SessionData sessionData) {
+        return new AllCapabilitiesConnector(configuration, sessionData);
+    }
+
     @Override
     public AllFoldersConnector getAllFoldersConnector(SessionData sessionData, String rootFolderId, String language) {
         return new AllFoldersConnector(configuration, sessionData, rootFolderId, language);
