@@ -49,9 +49,14 @@
 
 package com.openexchange.mobile.api.facade.endpoints.responses.ctos;
 
+import java.util.List;
+
 import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import com.openexchange.mobile.api.facade.models.Capability;
 import com.openexchange.mobile.api.facade.models.Config;
+import com.openexchange.mobile.api.facade.utils.ListUtil;
+import com.openexchange.mobile.api.facade.utils.MapFunction;
 
 import lombok.Value;
 
@@ -59,23 +64,36 @@ import lombok.Value;
 @JsonInclude(JsonInclude.Include.NON_NULL)
 public class ConfigCto {
 
+    private static final MapFunction<Capability, CapabilityCto> capabilitiesMapFunction = new MapFunction<Capability, CapabilityCto>() {
+
+        @Override
+        public CapabilityCto map(Capability capability) {
+            return new CapabilityCto(capability);
+        }
+
+    };
+
     @JsonInclude(JsonInclude.Include.NON_DEFAULT)
-    private boolean purgeOnDeletion;
+    boolean purgeOnDeletion;
 
     @JsonProperty("maxUploadSize")
-    private Long maxSize;
+    Long maxSize;
 
     @JsonProperty("maxUploadAttachmentSize")
-    private Long maxAttachmentSize;
+    Long maxAttachmentSize;
 
     @JsonInclude(JsonInclude.Include.NON_DEFAULT)
-    private boolean deleteDraftOnTransport;
+    boolean deleteDraftOnTransport;
+
+    @JsonInclude(JsonInclude.Include.NON_EMPTY)
+    List<CapabilityCto> capabilities;
 
     public ConfigCto(Config config) {
         purgeOnDeletion = config.isPurgeOnDeletion();
         maxSize = config.getMaxSize();
         maxAttachmentSize = config.getMaxAttachmentSize();
         deleteDraftOnTransport = config.isDeleteDraftOnTransport();
+        capabilities = ListUtil.map(config.getCapabilities(), capabilitiesMapFunction);
     }
 
 }
